@@ -59,7 +59,7 @@ class ListenerTestCases(TestCase):
         # we now have rendered content
         self.assertHTMLEqual(
                 page1.content_rendered,
-                '<h1>Hello World</h1>')
+                '<h1 id="hello-world">\nHello World\n</h1>')
 
     def test_hash_if_password(self):
         """A hash is generated on save if page has password"""
